==> vlc-0.8.1337.tar.bz2: vlc-0.8.1337/modules/misc/dummy/dummy.h <==
/*****************************************************************************
 * dummy.h : dummy plugin for vlc
 *****************************************************************************
 * Copyright (C) 2000, 2001, 2002 VideoLAN
 * $Id: dummy.h 10101 2005-03-02 16:47:31Z robux4 $
 *
 * Authors: Samuel Hocevar <sam@zoy.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

/*****************************************************************************
 * External prototypes
 *****************************************************************************/
int  E_(OpenIntf)     ( vlc_object_t * );

int  E_(OpenAccess)   ( vlc_object_t * );

int  E_(OpenDemux)    ( vlc_object_t * );
void E_(CloseDemux)   ( vlc_object_t * );

int  E_(OpenDecoder)  ( vlc_object_t * );
void E_(CloseDecoder) ( vlc_object_t * );

int  E_(OpenEncoder)  ( vlc_object_t * );
void E_(CloseEncoder) ( vlc_object_t * );

int  E_(OpenAudio)    ( vlc_object_t * );

int  E_(OpenVideo)    ( vlc_object_t * );

int  E_(OpenRenderer) ( vlc_object_t * );

==> vlc-0.9.5.tar.bz2: vlc-0.9.5/modules/misc/dummy/dummy.h <==
/*****************************************************************************
 * dummy.h : dummy plugin for vlc
 *****************************************************************************
 * Copyright (C) 2000, 2001, 2002 the VideoLAN team
 * $Id: a31c872b699e55e7be5d3d5b9de16181a3ec42eb $
 *
 * Authors: Samuel Hocevar <sam@zoy.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

/*****************************************************************************
 * External prototypes
 *****************************************************************************/
int  OpenIntf     ( vlc_object_t * );

int  OpenAccess   ( vlc_object_t * );

int  OpenDemux    ( vlc_object_t * );
void CloseDemux   ( vlc_object_t * );

int  OpenDecoder  ( vlc_object_t * );
void CloseDecoder ( vlc_object_t * );

int  OpenEncoder  ( vlc_object_t * );
void CloseEncoder ( vlc_object_t * );

int  OpenAudio    ( vlc_object_t * );

int  OpenVideo    ( vlc_object_t * );

int  OpenRenderer ( vlc_object_t * );
